<?php

if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}

class emergencyWPContactsTable extends WP_List_Table {

	public $total_items;
	public $total_pages;
	public $per_page;
    public $status;

	/**
	 * Constructor, we override the parent to pass our own arguments
	 * We usually focus on three parameters: singular and plural labels, as well as whether the class supports AJAX.
	 */
	function __construct() {
		parent::__construct( array(
			'singular' => __( 'Contact', 'emergencywp' ), // singular name of the listed records
			'plural'   => __( 'Contacts', 'emergencywp' ), // plural name of the listed records
			'ajax'     => false, // does this table support ajax?
		) );
	}

	protected function get_views() {
		return array(
			"all"       => __("<a href='admin.php?page=emergencywp_contacts'>All</a>",'emergencywp'),
			"published" => __("<a href='admin.php?page=emergencywp_contacts&status=publish'>Published</a>",'emergencywp'),
			"trashed"   => __("<a href='admin.php?page=emergencywp_contacts&status=trash'>Trashed</a>",'emergencywp')
		);
	}

	public function get_bulk_actions() {

		return array(
			'emergencywp_contacts_delete' => __( 'Delete', 'emergencywp' )
		);

	}

	/**
	 * Render the bulk edit checkbox
	 *
	 * @param array $item
	 *
	 * @return string
	 */
	function column_cb( $item ) {
		return sprintf(
			'<input type="checkbox" name="bulk-delete[]" value="%s" />', $item['ID']
		);
	}

	/**
	 *  Associative array of columns
	 *
	 * @return array
	 */
	function get_columns() {
		return [
			'cb'      => '<input type="checkbox" />',
            'name'    => __( 'Name', 'emergencywp' ),
            'thumb' => __('Image', 'emergencywp'),
			'email'    => __( 'Email', 'emergencywp' )
		];
	}

	/**
	 * Columns to make sortable.
	 *
	 * @return array
	 */
	public function get_sortable_columns() {
		return array(
			'name' => array( 'name', true )
		);
	}

	/** Text displayed when no customer data is available */
	public function no_items() {
		_e( 'No contacts available.', 'sp' );
	}

	/**
	 * Render a column when no column specific method exist.
	 *
	 * @param array $item
	 * @param string $column_name
	 *
	 * @return mixed
	 */
	public function column_default( $item, $column_name ) {
		switch ( $column_name ) {
			case 'email':
				return $item[ $column_name ];
            case 'thumb':
                $thumbEmail = $item['email'];
                $defaultAvatar = EMERGENCY_WP_PLUGIN_URL . 'assets/images/user01.gif';
                return '<div class="avatar" title="Source: Gravatar.com"
                                 style="background-image: url(&quot;https://2.gravatar.com/avatar/'.md5(strtolower(trim($thumbEmail))).'?s=400&amp;d='.urlencode($defaultAvatar).'&amp;r=g&quot;);"></div>';
			default:
				return print_r( $item, true ); //Show the whole array for troubleshooting purposes
		}
	}

	/**
	 * Method for name column
	 *
	 * @param array $item an array of DB data
	 *
	 * @return string
	 */
	function column_name( $item ) {

		$delete_nonce = wp_create_nonce( 'emergencywp_contacts' );
		$edit_nonce = wp_create_nonce( 'emergencywp_contacts' );

		$title = sprintf( '<a href="?post_type=emergencywp_contacts&page=%s&action=%s&post=%s&_wpnonce=%s">' . $item['name'] . '</a>', sanitize_text_field( $_REQUEST['page'] ), 'edit', absint( $item['ID'] ), $delete_nonce );
        if($item['post_status'] == 'trash') {
            $actions = [
                'edit' => sprintf('<a href="?post_type=emergencywp_contacts&page=%s&action=%s&post=%s&_wpnonce=%s">' . __('Edit', 'emergencywp') . '</a>', sanitize_text_field($_REQUEST['page']), 'edit', absint($item['ID']), $delete_nonce),
                'delete' => sprintf('<a href="?post_type=emergencywp_contacts&page=%s&action=%s&post=%s&_wpnonce=%s">' . __('Delete', 'emergencywp') . '</a>', sanitize_text_field($_REQUEST['page']), 'delete', absint($item['ID']), $edit_nonce)
            ];
        } else {
            $actions = [
                'edit' => sprintf('<a href="?post_type=emergencywp_contacts&page=%s&action=%s&post=%s&_wpnonce=%s">' . __('Edit', 'emergencywp') . '</a>', sanitize_text_field($_REQUEST['page']), 'edit', absint($item['ID']), $delete_nonce),
                'trash' => sprintf('<a href="?post_type=emergencywp_contacts&page=%s&action=%s&post=%s&_wpnonce=%s">' . __('Move to trash', 'emergencywp') . '</a>', sanitize_text_field($_REQUEST['page']), 'trash', absint($item['ID']), $edit_nonce)
            ];
        }

		return $title . $this->row_actions( $actions );
	}
	/**
	 * Prepare the table with different parameters, pagination, columns and table elements
	 */
	function prepare_items() {
		global $wpdb;

		$screen = get_current_screen();
		$columns = $this->get_columns();
		$hidden = get_hidden_columns( $screen );
		$sortable = $this->get_sortable_columns();

		$this->_column_headers = array( $columns, $hidden, $sortable );
        if(!empty($this->status)){
            $_GET['status'] = $this->status;
        }
		$args = array(
			'status' => isset( $_GET['status'] ) ? sanitize_text_field($_GET['status']) : false
		);

		/* -- Preparing your query -- */
		$query = "SELECT * FROM $wpdb->posts WHERE post_type = 'emergencywp_contacts' ";

		if(isset($_GET['status'])) {
			$query .= ' AND post_status = "'.sanitize_text_field($_GET['status']).'" ';
		} else {
			$query .= " AND post_status != 'auto-draft' AND post_status != 'trash'";
		}
		/* -- Ordering parameters -- */
		//Parameters that are going to be used to order the result
		$orderby = ! empty( $_GET["orderby"] ) ? mysqli_real_escape_string( $wpdb, sanitize_text_field($_GET["orderby"]) ) : 'ASC';
		$order   = ! empty( $_GET["order"] ) ? mysqli_real_escape_string( $wpdb, sanitize_text_field($_GET["order"]) ) : '';
		if ( ! empty( $orderby ) & ! empty( $order ) ) {
			$query .= ' ORDER BY ' . $orderby . ' ' . $order;
		}

		/* -- Pagination parameters -- */
		//Number of elements in your table?
		$totalitems = $wpdb->query( $query ); //return the total number of affected rows

		$this->total_items = $totalitems;

		//How many to display per page?
		$perpage = 15;
		//Which page is this?
		$paged = ! empty( $_GET["paged"] ) ? mysqli_real_escape_string( $wpdb, sanitize_text_field($_GET["paged"]) ) : '';
		//Page Number
		if ( empty( $paged ) || ! is_numeric( $paged ) || $paged <= 0 ) {
			$paged = 1;
		} //How many pages do we have in total?
		$totalpages = ceil( $totalitems / $perpage );
		//adjust the query to take pagination into account
		if ( ! empty( $paged ) && ! empty( $perpage ) ) {
			$offset = ( $paged - 1 ) * $perpage;
			$query .= ' LIMIT ' . (int) $offset . ',' . (int) $perpage;
		}
		/* -- Register the pagination -- */
		$this->set_pagination_args( array(
			"total_items" => $totalitems,
			"total_pages" => $totalpages,
			"per_page"    => $perpage,
		) );
		//The pagination links are automatically built according to those parameters

		/* -- Register the Columns -- */
		$columns = $this->get_columns();

		/* -- Fetch the items -- */
		$items = $wpdb->get_results( $query, 'ARRAY_A' );

		foreach ( $items as $key => $value ) {
			$firstName_value           = get_post_meta( $value['ID'], 'emergencywp_contacts_firstName' );
			$lastName_value           = get_post_meta( $value['ID'], 'emergencywp_contacts_lastName' );
			//$items[ $key ]['Name'] = $new_value;
			$items[ $key ]['name'] = $firstName_value[0] . ' '. $lastName_value[0];

			$new_value           = get_post_meta( $value['ID'], 'emergencywp_contacts_email' );
			$items[ $key ]['email'] = $new_value[0];
		}

		$this->items = $items;

	}

}

?>